==> mx-usb-unmounter_19.01.tar.xz: mx-usb-unmounter/translations/mx-usb-unmounter_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>usbunmounter</name>
    <message>
        <location filename="../usbunmounter.ui" line="27"/>
        <location filename="../usbunmounter.cpp" line="208"/>
        <location filename="../usbunmounter.cpp" line="317"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>MX USB Unmounter</source>
        <translation>MX USB Unmounter</translation>
    </message>
    <message>
        <location filename="../usbunmounter.ui" line="51"/>
        <source>Double-Click to Unmount</source>
        <translation>Doppelklick, um Auszuhängen</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="138"/>
        <source>Volume</source>
        <translation>Speichereinheit (&apos;volume&apos;)</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="181"/>
        <source>No Removable Device</source>
        <translation>kein entfernbares Speichermedium</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="205"/>
        <source>Unmounting </source>
        <translation>Aushängen</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="207"/>
        <source>Other partitions still mounted on device</source>
        <translation>Auf dem Gerät sind jetzt noch andere Partitionen eingehängt</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="276"/>
        <source>Unable to  Unmount, Device in Use</source>
        <translation>Aushängen unmöglich weil Gerät noch in Benutzung ist</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="316"/>
        <source>About MX USB Unmounter</source>
        <translation>Impressum von MX USB Unmounter</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="317"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="318"/>
        <source>Quickly Unmount Removable Media</source>
        <translation>schnelles unmount von entfernbaren Speichermedien</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="320"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="321"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="322"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
</context>
</TS>

==> mx-usb-unmounter_23.02.tar.xz: mx-usb-unmounter/translations/mx-usb-unmounter_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>usbunmounter</name>
    <message>
        <location filename="../usbunmounter.ui" line="27"/>
        <location filename="../usbunmounter.cpp" line="208"/>
        <location filename="../usbunmounter.cpp" line="317"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>MX USB Unmounter</source>
        <translation>MX USB Unmounter</translation>
    </message>
    <message>
        <location filename="../usbunmounter.ui" line="51"/>
        <source>Double-Click to Unmount</source>
        <translation>Doppelklick, um Auszuhängen</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="138"/>
        <source>Volume</source>
        <translation>Speichereinheit (&apos;volume&apos;)</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="181"/>
        <source>No Removable Device</source>
        <translation>kein entfernbares Speichermedium</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="205"/>
        <source>Unmounting </source>
        <translation>Aushängen</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="207"/>
        <source>Other partitions still mounted on device</source>
        <translation>Auf dem Gerät sind jetzt noch andere Partitionen eingehängt</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="276"/>
        <source>Unable to  Unmount, Device in Use</source>
        <translation>Aushängen unmöglich weil Gerät noch in Benutzung ist</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="316"/>
        <source>About MX USB Unmounter</source>
        <translation>Impressum von MX USB Unmounter</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="317"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="318"/>
        <source>Quickly Unmount Removable Media</source>
        <translation>schnelles unmount von entfernbaren Speichermedien</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="320"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="321"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="322"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
</context>
</TS>
